Page 36 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 36

Home

    Weishaupt was such a master at perverting Christian
    doctrine that he gleefully boasted of the acceptance of

    You can't imagine what respect and curiosity my
    priest-degree has raised; and, which is wonderful, a
    famous Protestant divine, who is now of the Order, is
    persuaded that the religion contained in it is the true
    sense of Christianity. O MAN, MAN! TO WHAT
    MAY'ST THOU NOT BE PERSUADED. Who would
    imagine that I was to be the founder of a new religion.®

    who would insist on being a man of consequence among
    us, and is really a man of talents, and of a right way of
    thinking, is eternally besotted. Augustus is in the worst
    estimation imaginable. Alcibiades sits the day long with
    the vintner's pretty wife, and there he sighs and pines. A
    few days ago, at Corinth, Tiberius attempted to ravish
    the wife of Democides, and her husband came in upon
    them... . When the worthy man Marcus Aurelius comes
    to Athens (Munich) what will he think? What a meeting
    with dissolute immoral wretches, whore-masters, liars,
    bankrupts, braggarts, and vain fools!”

    31

    The Iluminati

    his Priest degree:

    And what of the moral character of these molders of

    the minds of men and would be rulers of the world? For

    an answer we turn to their own confessions. In a letter to

    Cato (Zwack) Spartacus (Weishaupt) writes:

    What shall I do? I am deprived of all help. Socrates,